1.0.0 API documentation: GLM_GTC_matrix_integer

| 1.0.0 API documentation

Typedefs
GLM_GTC_matrix_integer
Recommended extensions

## Typedefs
typedef mat< 2, 2, int, highp > | highp_imat2
| High-qualifier signed integer 2x2 matrix. More...
typedef mat< 2, 2, int, highp > | highp_imat2x2
| High-qualifier signed integer 2x2 matrix. More...
typedef mat< 2, 3, int, highp > | highp_imat2x3
| High-qualifier signed integer 2x3 matrix. More...
typedef mat< 2, 4, int, highp > | highp_imat2x4
| High-qualifier signed integer 2x4 matrix. More...
typedef mat< 3, 3, int, highp > | highp_imat3
| High-qualifier signed integer 3x3 matrix. More...
typedef mat< 3, 2, int, highp > | highp_imat3x2
| High-qualifier signed integer 3x2 matrix. More...
typedef mat< 3, 3, int, highp > | highp_imat3x3
| High-qualifier signed integer 3x3 matrix. More...
typedef mat< 3, 4, int, highp > | highp_imat3x4
| High-qualifier signed integer 3x4 matrix. More...
typedef mat< 4, 4, int, highp > | highp_imat4
| High-qualifier signed integer 4x4 matrix. More...
typedef mat< 4, 2, int, highp > | highp_imat4x2
| High-qualifier signed integer 4x2 matrix. More...
typedef mat< 4, 3, int, highp > | highp_imat4x3
| High-qualifier signed integer 4x3 matrix. More...
typedef mat< 4, 4, int, highp > | highp_imat4x4
| High-qualifier signed integer 4x4 matrix. More...
typedef mat< 2, 2, uint, highp > | highp_umat2
| High-qualifier unsigned integer 2x2 matrix. More...
typedef mat< 2, 2, uint, highp > | highp_umat2x2
| High-qualifier unsigned integer 2x2 matrix. More...
typedef mat< 2, 3, uint, highp > | highp_umat2x3
| High-qualifier unsigned integer 2x3 matrix. More...
typedef mat< 2, 4, uint, highp > | highp_umat2x4
| High-qualifier unsigned integer 2x4 matrix. More...
typedef mat< 3, 3, uint, highp > | highp_umat3
| High-qualifier unsigned integer 3x3 matrix. More...
typedef mat< 3, 2, uint, highp > | highp_umat3x2
| High-qualifier unsigned integer 3x2 matrix. More...
typedef mat< 3, 3, uint, highp > | highp_umat3x3
| High-qualifier unsigned integer 3x3 matrix. More...
typedef mat< 3, 4, uint, highp > | highp_umat3x4
| High-qualifier unsigned integer 3x4 matrix. More...
typedef mat< 4, 4, uint, highp > | highp_umat4
| High-qualifier unsigned integer 4x4 matrix. More...
typedef mat< 4, 2, uint, highp > | highp_umat4x2
| High-qualifier unsigned integer 4x2 matrix. More...
typedef mat< 4, 3, uint, highp > | highp_umat4x3
| High-qualifier unsigned integer 4x3 matrix. More...
typedef mat< 4, 4, uint, highp > | highp_umat4x4
| High-qualifier unsigned integer 4x4 matrix. More...
typedef mat< 2, 2, int, lowp > | lowp_imat2
| Low-qualifier signed integer 2x2 matrix. More...
typedef mat< 2, 2, int, lowp > | lowp_imat2x2
| Low-qualifier signed integer 2x2 matrix. More...
typedef mat< 2, 3, int, lowp > | lowp_imat2x3
| Low-qualifier signed integer 2x3 matrix. More...
typedef mat< 2, 4, int, lowp > | lowp_imat2x4
| Low-qualifier signed integer 2x4 matrix. More...
typedef mat< 3, 3, int, lowp > | lowp_imat3
| Low-qualifier signed integer 3x3 matrix. More...
typedef mat< 3, 2, int, lowp > | lowp_imat3x2
| Low-qualifier signed integer 3x2 matrix. More...
typedef mat< 3, 3, int, lowp > | lowp_imat3x3
| Low-qualifier signed integer 3x3 matrix. More...
typedef mat< 3, 4, int, lowp > | lowp_imat3x4
| Low-qualifier signed integer 3x4 matrix. More...
typedef mat< 4, 4, int, lowp > | lowp_imat4
| Low-qualifier signed integer 4x4 matrix. More...
typedef mat< 4, 2, int, lowp > | lowp_imat4x2
| Low-qualifier signed integer 4x2 matrix. More...
typedef mat< 4, 3, int, lowp > | lowp_imat4x3
| Low-qualifier signed integer 4x3 matrix. More...
typedef mat< 4, 4, int, lowp > | lowp_imat4x4
| Low-qualifier signed integer 4x4 matrix. More...
typedef mat< 2, 2, uint, lowp > | lowp_umat2
| Low-qualifier unsigned integer 2x2 matrix. More...
typedef mat< 2, 2, uint, lowp > | lowp_umat2x2
| Low-qualifier unsigned integer 2x2 matrix. More...
typedef mat< 2, 3, uint, lowp > | lowp_umat2x3
| Low-qualifier unsigned integer 2x3 matrix. More...
typedef mat< 2, 4, uint, lowp > | lowp_umat2x4
| Low-qualifier unsigned integer 2x4 matrix. More...
typedef mat< 3, 3, uint, lowp > | lowp_umat3
| Low-qualifier unsigned integer 3x3 matrix. More...
typedef mat< 3, 2, uint, lowp > | lowp_umat3x2
| Low-qualifier unsigned integer 3x2 matrix. More...
typedef mat< 3, 3, uint, lowp > | lowp_umat3x3
| Low-qualifier unsigned integer 3x3 matrix. More...
typedef mat< 3, 4, uint, lowp > | lowp_umat3x4
| Low-qualifier unsigned integer 3x4 matrix. More...
typedef mat< 4, 4, uint, lowp > | lowp_umat4
| Low-qualifier unsigned integer 4x4 matrix. More...
typedef mat< 4, 2, uint, lowp > | lowp_umat4x2
| Low-qualifier unsigned integer 4x2 matrix. More...
typedef mat< 4, 3, uint, lowp > | lowp_umat4x3
| Low-qualifier unsigned integer 4x3 matrix. More...
typedef mat< 4, 4, uint, lowp > | lowp_umat4x4
| Low-qualifier unsigned integer 4x4 matrix. More...
typedef mat< 2, 2, int, mediump > | mediump_imat2
| Medium-qualifier signed integer 2x2 matrix. More...
typedef mat< 2, 2, int, mediump > | mediump_imat2x2
| Medium-qualifier signed integer 2x2 matrix. More...
typedef mat< 2, 3, int, mediump > | mediump_imat2x3
| Medium-qualifier signed integer 2x3 matrix. More...
typedef mat< 2, 4, int, mediump > | mediump_imat2x4
| Medium-qualifier signed integer 2x4 matrix. More...
typedef mat< 3, 3, int, mediump > | mediump_imat3
| Medium-qualifier signed integer 3x3 matrix. More...
typedef mat< 3, 2, int, mediump > | mediump_imat3x2
| Medium-qualifier signed integer 3x2 matrix. More...
typedef mat< 3, 3, int, mediump > | mediump_imat3x3
| Medium-qualifier signed integer 3x3 matrix. More...
typedef mat< 3, 4, int, mediump > | mediump_imat3x4
| Medium-qualifier signed integer 3x4 matrix. More...
typedef mat< 4, 4, int, mediump > | mediump_imat4
| Medium-qualifier signed integer 4x4 matrix. More...
typedef mat< 4, 2, int, mediump > | mediump_imat4x2
| Medium-qualifier signed integer 4x2 matrix. More...
typedef mat< 4, 3, int, mediump > | mediump_imat4x3
| Medium-qualifier signed integer 4x3 matrix. More...
typedef mat< 4, 4, int, mediump > | mediump_imat4x4
| Medium-qualifier signed integer 4x4 matrix. More...
typedef mat< 2, 2, uint, mediump > | mediump_umat2
| Medium-qualifier unsigned integer 2x2 matrix. More...
typedef mat< 2, 2, uint, mediump > | mediump_umat2x2
| Medium-qualifier unsigned integer 2x2 matrix. More...
typedef mat< 2, 3, uint, mediump > | mediump_umat2x3
| Medium-qualifier unsigned integer 2x3 matrix. More...
typedef mat< 2, 4, uint, mediump > | mediump_umat2x4
| Medium-qualifier unsigned integer 2x4 matrix. More...
typedef mat< 3, 3, uint, mediump > | mediump_umat3
| Medium-qualifier unsigned integer 3x3 matrix. More...
typedef mat< 3, 2, uint, mediump > | mediump_umat3x2
| Medium-qualifier unsigned integer 3x2 matrix. More...
typedef mat< 3, 3, uint, mediump > | mediump_umat3x3
| Medium-qualifier unsigned integer 3x3 matrix. More...
typedef mat< 3, 4, uint, mediump > | mediump_umat3x4
| Medium-qualifier unsigned integer 3x4 matrix. More...
typedef mat< 4, 4, uint, mediump > | mediump_umat4
| Medium-qualifier unsigned integer 4x4 matrix. More...
typedef mat< 4, 2, uint, mediump > | mediump_umat4x2
| Medium-qualifier unsigned integer 4x2 matrix. More...
typedef mat< 4, 3, uint, mediump > | mediump_umat4x3
| Medium-qualifier unsigned integer 4x3 matrix. More...
typedef mat< 4, 4, uint, mediump > | mediump_umat4x4
| Medium-qualifier unsigned integer 4x4 matrix. More...

## Detailed Description

Include <glm/gtc/matrix_integer.hpp> to use the features of this extension.

Defines a number of matrices with integer types.

## Typedef Documentation

## ◆ highp_imat2

typedef mat<2, 2, int, highp> highp_imat2

High-qualifier signed integer 2x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 37 of file gtc/matrix_integer.hpp.

## ◆ highp_imat2x2

typedef mat< 2, 2, int, highp > highp_imat2x2

High-qualifier signed integer 2x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 814 of file fwd.hpp.

## ◆ highp_imat2x3

typedef mat< 2, 3, int, highp > highp_imat2x3

High-qualifier signed integer 2x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 815 of file fwd.hpp.

## ◆ highp_imat2x4

typedef mat< 2, 4, int, highp > highp_imat2x4

High-qualifier signed integer 2x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 816 of file fwd.hpp.

## ◆ highp_imat3

typedef mat<3, 3, int, highp> highp_imat3

High-qualifier signed integer 3x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 41 of file gtc/matrix_integer.hpp.

## ◆ highp_imat3x2

typedef mat< 3, 2, int, highp > highp_imat3x2

High-qualifier signed integer 3x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 817 of file fwd.hpp.

## ◆ highp_imat3x3

typedef mat< 3, 3, int, highp > highp_imat3x3

High-qualifier signed integer 3x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 818 of file fwd.hpp.

## ◆ highp_imat3x4

typedef mat< 3, 4, int, highp > highp_imat3x4

High-qualifier signed integer 3x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 819 of file fwd.hpp.

## ◆ highp_imat4

typedef mat<4, 4, int, highp> highp_imat4

High-qualifier signed integer 4x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 45 of file gtc/matrix_integer.hpp.

## ◆ highp_imat4x2

typedef mat< 4, 2, int, highp > highp_imat4x2

High-qualifier signed integer 4x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 820 of file fwd.hpp.

## ◆ highp_imat4x3

typedef mat< 4, 3, int, highp > highp_imat4x3

High-qualifier signed integer 4x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 821 of file fwd.hpp.

## ◆ highp_imat4x4

typedef mat< 4, 4, int, highp > highp_imat4x4

High-qualifier signed integer 4x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 822 of file fwd.hpp.

## ◆ highp_umat2

typedef mat<2, 2, uint, highp> highp_umat2

High-qualifier unsigned integer 2x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 186 of file gtc/matrix_integer.hpp.

## ◆ highp_umat2x2

typedef mat< 2, 2, uint, highp > highp_umat2x2

High-qualifier unsigned integer 2x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1021 of file fwd.hpp.

## ◆ highp_umat2x3

typedef mat< 2, 3, uint, highp > highp_umat2x3

High-qualifier unsigned integer 2x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1022 of file fwd.hpp.

## ◆ highp_umat2x4

typedef mat< 2, 4, uint, highp > highp_umat2x4

High-qualifier unsigned integer 2x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1023 of file fwd.hpp.

## ◆ highp_umat3

typedef mat<3, 3, uint, highp> highp_umat3

High-qualifier unsigned integer 3x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 190 of file gtc/matrix_integer.hpp.

## ◆ highp_umat3x2

typedef mat< 3, 2, uint, highp > highp_umat3x2

High-qualifier unsigned integer 3x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1024 of file fwd.hpp.

## ◆ highp_umat3x3

typedef mat< 3, 3, uint, highp > highp_umat3x3

High-qualifier unsigned integer 3x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1025 of file fwd.hpp.

## ◆ highp_umat3x4

typedef mat< 3, 4, uint, highp > highp_umat3x4

High-qualifier unsigned integer 3x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1026 of file fwd.hpp.

## ◆ highp_umat4

typedef mat<4, 4, uint, highp> highp_umat4

High-qualifier unsigned integer 4x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 194 of file gtc/matrix_integer.hpp.

## ◆ highp_umat4x2

typedef mat< 4, 2, uint, highp > highp_umat4x2

High-qualifier unsigned integer 4x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1027 of file fwd.hpp.

## ◆ highp_umat4x3

typedef mat< 4, 3, uint, highp > highp_umat4x3

High-qualifier unsigned integer 4x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1028 of file fwd.hpp.

## ◆ highp_umat4x4

typedef mat< 4, 4, uint, highp > highp_umat4x4

High-qualifier unsigned integer 4x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1029 of file fwd.hpp.

## ◆ lowp_imat2

typedef mat<2, 2, int, lowp> lowp_imat2

Low-qualifier signed integer 2x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 136 of file gtc/matrix_integer.hpp.

## ◆ lowp_imat2x2

typedef mat< 2, 2, int, lowp > lowp_imat2x2

Low-qualifier signed integer 2x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 794 of file fwd.hpp.

## ◆ lowp_imat2x3

typedef mat< 2, 3, int, lowp > lowp_imat2x3

Low-qualifier signed integer 2x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 795 of file fwd.hpp.

## ◆ lowp_imat2x4

typedef mat< 2, 4, int, lowp > lowp_imat2x4

Low-qualifier signed integer 2x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 796 of file fwd.hpp.

## ◆ lowp_imat3

typedef mat<3, 3, int, lowp> lowp_imat3

Low-qualifier signed integer 3x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 140 of file gtc/matrix_integer.hpp.

## ◆ lowp_imat3x2

typedef mat< 3, 2, int, lowp > lowp_imat3x2

Low-qualifier signed integer 3x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 797 of file fwd.hpp.

## ◆ lowp_imat3x3

typedef mat< 3, 3, int, lowp > lowp_imat3x3

Low-qualifier signed integer 3x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 798 of file fwd.hpp.

## ◆ lowp_imat3x4

typedef mat< 3, 4, int, lowp > lowp_imat3x4

Low-qualifier signed integer 3x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 799 of file fwd.hpp.

## ◆ lowp_imat4

typedef mat<4, 4, int, lowp> lowp_imat4

Low-qualifier signed integer 4x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 144 of file gtc/matrix_integer.hpp.

## ◆ lowp_imat4x2

typedef mat< 4, 2, int, lowp > lowp_imat4x2

Low-qualifier signed integer 4x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 800 of file fwd.hpp.

## ◆ lowp_imat4x3

typedef mat< 4, 3, int, lowp > lowp_imat4x3

Low-qualifier signed integer 4x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 801 of file fwd.hpp.

## ◆ lowp_imat4x4

typedef mat< 4, 4, int, lowp > lowp_imat4x4

Low-qualifier signed integer 4x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 802 of file fwd.hpp.

## ◆ lowp_umat2

typedef mat<2, 2, uint, lowp> lowp_umat2

Low-qualifier unsigned integer 2x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 285 of file gtc/matrix_integer.hpp.

## ◆ lowp_umat2x2

typedef mat< 2, 2, uint, lowp > lowp_umat2x2

Low-qualifier unsigned integer 2x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1001 of file fwd.hpp.

## ◆ lowp_umat2x3

typedef mat< 2, 3, uint, lowp > lowp_umat2x3

Low-qualifier unsigned integer 2x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1002 of file fwd.hpp.

## ◆ lowp_umat2x4

typedef mat< 2, 4, uint, lowp > lowp_umat2x4

Low-qualifier unsigned integer 2x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1003 of file fwd.hpp.

## ◆ lowp_umat3

typedef mat<3, 3, uint, lowp> lowp_umat3

Low-qualifier unsigned integer 3x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 289 of file gtc/matrix_integer.hpp.

## ◆ lowp_umat3x2

typedef mat< 3, 2, uint, lowp > lowp_umat3x2

Low-qualifier unsigned integer 3x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1004 of file fwd.hpp.

## ◆ lowp_umat3x3

typedef mat< 3, 3, uint, lowp > lowp_umat3x3

Low-qualifier unsigned integer 3x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1005 of file fwd.hpp.

## ◆ lowp_umat3x4

typedef mat< 3, 4, uint, lowp > lowp_umat3x4

Low-qualifier unsigned integer 3x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1006 of file fwd.hpp.

## ◆ lowp_umat4

typedef mat<4, 4, uint, lowp> lowp_umat4

Low-qualifier unsigned integer 4x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 293 of file gtc/matrix_integer.hpp.

## ◆ lowp_umat4x2

typedef mat< 4, 2, uint, lowp > lowp_umat4x2

Low-qualifier unsigned integer 4x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1007 of file fwd.hpp.

## ◆ lowp_umat4x3

typedef mat< 4, 3, uint, lowp > lowp_umat4x3

Low-qualifier unsigned integer 4x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1008 of file fwd.hpp.

## ◆ lowp_umat4x4

typedef mat< 4, 4, uint, lowp > lowp_umat4x4

Low-qualifier unsigned integer 4x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1009 of file fwd.hpp.

## ◆ mediump_imat2

typedef mat<2, 2, int, mediump> mediump_imat2

Medium-qualifier signed integer 2x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 86 of file gtc/matrix_integer.hpp.

## ◆ mediump_imat2x2

typedef mat< 2, 2, int, mediump > mediump_imat2x2

Medium-qualifier signed integer 2x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 804 of file fwd.hpp.

## ◆ mediump_imat2x3

typedef mat< 2, 3, int, mediump > mediump_imat2x3

Medium-qualifier signed integer 2x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 805 of file fwd.hpp.

## ◆ mediump_imat2x4

typedef mat< 2, 4, int, mediump > mediump_imat2x4

Medium-qualifier signed integer 2x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 806 of file fwd.hpp.

## ◆ mediump_imat3

typedef mat<3, 3, int, mediump> mediump_imat3

Medium-qualifier signed integer 3x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 90 of file gtc/matrix_integer.hpp.

## ◆ mediump_imat3x2

typedef mat< 3, 2, int, mediump > mediump_imat3x2

Medium-qualifier signed integer 3x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 807 of file fwd.hpp.

## ◆ mediump_imat3x3

typedef mat< 3, 3, int, mediump > mediump_imat3x3

Medium-qualifier signed integer 3x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 808 of file fwd.hpp.

## ◆ mediump_imat3x4

typedef mat< 3, 4, int, mediump > mediump_imat3x4

Medium-qualifier signed integer 3x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 809 of file fwd.hpp.

## ◆ mediump_imat4

typedef mat<4, 4, int, mediump> mediump_imat4

Medium-qualifier signed integer 4x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 94 of file gtc/matrix_integer.hpp.

## ◆ mediump_imat4x2

typedef mat< 4, 2, int, mediump > mediump_imat4x2

Medium-qualifier signed integer 4x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 810 of file fwd.hpp.

## ◆ mediump_imat4x3

typedef mat< 4, 3, int, mediump > mediump_imat4x3

Medium-qualifier signed integer 4x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 811 of file fwd.hpp.

## ◆ mediump_imat4x4

typedef mat< 4, 4, int, mediump > mediump_imat4x4

Medium-qualifier signed integer 4x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 812 of file fwd.hpp.

## ◆ mediump_umat2

typedef mat<2, 2, uint, mediump> mediump_umat2

Medium-qualifier unsigned integer 2x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 235 of file gtc/matrix_integer.hpp.

## ◆ mediump_umat2x2

typedef mat< 2, 2, uint, mediump > mediump_umat2x2

Medium-qualifier unsigned integer 2x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1011 of file fwd.hpp.

## ◆ mediump_umat2x3

typedef mat< 2, 3, uint, mediump > mediump_umat2x3

Medium-qualifier unsigned integer 2x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1012 of file fwd.hpp.

## ◆ mediump_umat2x4

typedef mat< 2, 4, uint, mediump > mediump_umat2x4

Medium-qualifier unsigned integer 2x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1013 of file fwd.hpp.

## ◆ mediump_umat3

typedef mat<3, 3, uint, mediump> mediump_umat3

Medium-qualifier unsigned integer 3x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 239 of file gtc/matrix_integer.hpp.

## ◆ mediump_umat3x2

typedef mat< 3, 2, uint, mediump > mediump_umat3x2

Medium-qualifier unsigned integer 3x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1014 of file fwd.hpp.

## ◆ mediump_umat3x3

typedef mat< 3, 3, uint, mediump > mediump_umat3x3

Medium-qualifier unsigned integer 3x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1015 of file fwd.hpp.

## ◆ mediump_umat3x4

typedef mat< 3, 4, uint, mediump > mediump_umat3x4

Medium-qualifier unsigned integer 3x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1016 of file fwd.hpp.

## ◆ mediump_umat4

typedef mat<4, 4, uint, mediump> mediump_umat4

Medium-qualifier unsigned integer 4x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 243 of file gtc/matrix_integer.hpp.

## ◆ mediump_umat4x2

typedef mat< 4, 2, uint, mediump > mediump_umat4x2

Medium-qualifier unsigned integer 4x2 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1017 of file fwd.hpp.

## ◆ mediump_umat4x3

typedef mat< 4, 3, uint, mediump > mediump_umat4x3

Medium-qualifier unsigned integer 4x3 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1018 of file fwd.hpp.

## ◆ mediump_umat4x4

typedef mat< 4, 4, uint, mediump > mediump_umat4x4

Medium-qualifier unsigned integer 4x4 matrix.

See also
  GLM_GTC_matrix_integer

Definition at line 1019 of file fwd.hpp.